==> chaosmesh-model-5.0.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/FailKernRequestFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface FailKernRequestFluent<A extends FailKernRequestFluent<A>> extends Fluent<A> {


    public A addToCallchain(int index,Frame item);
    public A setToCallchain(int index,Frame item);
    public A addToCallchain(Frame... items);
    public A addAllToCallchain(Collection<Frame> items);
    public A removeFromCallchain(Frame... items);
    public A removeAllFromCallchain(Collection<Frame> items);
    public A removeMatchingFromCallchain(Predicate<FrameBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildCallchain instead.
 * @return The buildable object.
 */
@Deprecated public List<Frame> getCallchain();
    public List<Frame> buildCallchain();
    public Frame buildCallchain(int index);
    public Frame buildFirstCallchain();
    public Frame buildLastCallchain();
    public Frame buildMatchingCallchain(Predicate<FrameBuilder> predicate);
    public Boolean hasMatchingCallchain(Predicate<FrameBuilder> predicate);
    public A withCallchain(List<Frame> callchain);
    public A withCallchain(Frame... callchain);
    public Boolean hasCallchain();
    public A addNewCallchain(String funcname,String parameters,String predicate);
    public FailKernRequestFluent.CallchainNested<A> addNewCallchain();
    public FailKernRequestFluent.CallchainNested<A> addNewCallchainLike(Frame item);
    public FailKernRequestFluent.CallchainNested<A> setNewCallchainLike(int index,Frame item);
    public FailKernRequestFluent.CallchainNested<A> editCallchain(int index);
    public FailKernRequestFluent.CallchainNested<A> editFirstCallchain();
    public FailKernRequestFluent.CallchainNested<A> editLastCallchain();
    public FailKernRequestFluent.CallchainNested<A> editMatchingCallchain(Predicate<FrameBuilder> predicate);
    public Integer getFailtype();
    public A withFailtype(Integer failtype);
    public Boolean hasFailtype();
    public A addToHeaders(int index,String item);
    public A setToHeaders(int index,String item);
    public A addToHeaders(String... items);
    public A addAllToHeaders(Collection<String> items);
    public A removeFromHeaders(String... items);
    public A removeAllFromHeaders(Collection<String> items);
    public List<String> getHeaders();
    public String getHeader(int index);
    public String getFirstHeader();
    public String getLastHeader();
    public String getMatchingHeader(Predicate<String> predicate);
    public Boolean hasMatchingHeader(Predicate<String> predicate);
    public A withHeaders(List<String> headers);
    public A withHeaders(String... headers);
    public Boolean hasHeaders();
    public A addNewHeader(String arg1);
    public A addNewHeader(StringBuilder arg1);
    public A addNewHeader(StringBuffer arg1);
    public Integer getProbability();
    public A withProbability(Integer probability);
    public Boolean hasProbability();
    public Integer getTimes();
    public A withTimes(Integer times);
    public Boolean hasTimes();
    public interface CallchainNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,FrameFluent<FailKernRequestFluent.CallchainNested<N>> {

            public N and();
            public N endCallchain();    }


}

==> chaosmesh-model-5.2.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/FailKernRequestFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface FailKernRequestFluent<A extends FailKernRequestFluent<A>> extends Fluent<A> {


    public A addToCallchain(int index,Frame item);
    public A setToCallchain(int index,Frame item);
    public A addToCallchain(Frame... items);
    public A addAllToCallchain(Collection<Frame> items);
    public A removeFromCallchain(Frame... items);
    public A removeAllFromCallchain(Collection<Frame> items);
    public A removeMatchingFromCallchain(Predicate<FrameBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildCallchain instead.
 * @return The buildable object.
 */
@Deprecated public List<Frame> getCallchain();
    public List<Frame> buildCallchain();
    public Frame buildCallchain(int index);
    public Frame buildFirstCallchain();
    public Frame buildLastCallchain();
    public Frame buildMatchingCallchain(Predicate<FrameBuilder> predicate);
    public Boolean hasMatchingCallchain(Predicate<FrameBuilder> predicate);
    public A withCallchain(List<Frame> callchain);
    public A withCallchain(Frame... callchain);
    public Boolean hasCallchain();
    public A addNewCallchain(String funcname,String parameters,String predicate);
    public FailKernRequestFluent.CallchainNested<A> addNewCallchain();
    public FailKernRequestFluent.CallchainNested<A> addNewCallchainLike(Frame item);
    public FailKernRequestFluent.CallchainNested<A> setNewCallchainLike(int index,Frame item);
    public FailKernRequestFluent.CallchainNested<A> editCallchain(int index);
    public FailKernRequestFluent.CallchainNested<A> editFirstCallchain();
    public FailKernRequestFluent.CallchainNested<A> editLastCallchain();
    public FailKernRequestFluent.CallchainNested<A> editMatchingCallchain(Predicate<FrameBuilder> predicate);
    public Integer getFailtype();
    public A withFailtype(Integer failtype);
    public Boolean hasFailtype();
    public A withNewFailtype(String arg1);
    public A withNewFailtype(int arg1);
    public A addToHeaders(int index,String item);
    public A setToHeaders(int index,String item);
    public A addToHeaders(String... items);
    public A addAllToHeaders(Collection<String> items);
    public A removeFromHeaders(String... items);
    public A removeAllFromHeaders(Collection<String> items);
    public List<String> getHeaders();
    public String getHeader(int index);
    public String getFirstHeader();
    public String getLastHeader();
    public String getMatchingHeader(Predicate<String> predicate);
    public Boolean hasMatchingHeader(Predicate<String> predicate);
    public A withHeaders(List<String> headers);
    public A withHeaders(String... headers);
    public Boolean hasHeaders();
    public A addNewHeader(String arg1);
    public A addNewHeader(StringBuilder arg1);
    public A addNewHeader(StringBuffer arg1);
    public Integer getProbability();
    public A withProbability(Integer probability);
    public Boolean hasProbability();
    public A withNewProbability(String arg1);
    public A withNewProbability(int arg1);
    public Integer getTimes();
    public A withTimes(Integer times);
    public Boolean hasTimes();
    public A withNewTimes(String arg1);
    public A withNewTimes(int arg1);
    public interface CallchainNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,FrameFluent<FailKernRequestFluent.CallchainNested<N>> {

            public N and();
            public N endCallchain();    }


}
